@@ -165,6 +165,10 @@ where
         }
     }
 
+    pub fn current_time(&self) -> T {
+        self.data.data.lock().current.clone()
+    }
+
     pub fn state(&self) -> &S {
         &self.data.state
     }
@@ -268,6 +272,10 @@ where
         }
     }
 
+    pub fn current_time(self) -> T {
+        self.target.data.lock().current.clone()
+    }
+
     pub fn spawn(self, f: impl Future<Output = ()> + Send + 'a) {
         Timewrap::spawn_inner(self.target, Box::pin(f), None);
     }
